/*
 *  Canon Inkjet Printer Driver for Linux
 *  Copyright CANON INC. 2022
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
 * NOTE:
 *  - As a special exception, this program is permissible to link with the
 *    libraries released as the binary modules.
 *  - If you write modifications of your own for these programs, it is your
 *    choice whether to permit this exception to apply to your modifications.
 *    If you do not wish that, delete this exception.
*/

#ifndef _COM_LOG_H_
#define _COM_LOG_H_

#include <stdio.h>
#include "config.h"

#ifdef DEBUG_LOG
#define DEBUG_PRINT( type, message ) fprintf( stderr, #type message )
#define DEBUG_PRINT2( type, f, a ) fprintf( stderr, #type f, a )
#define DEBUG_PRINT3( type, f, a, b ) fprintf( stderr, #type f, a, b )
#else
#define DEBUG_PRINT( type, message )
#define DEBUG_PRINT2( type, f, a )
#define DEBUG_PRINT3( type, f, a, b )
#endif

#define DEBUG_PRINT_PROGRAM_START() DEBUG_PRINT(DEBUG:, "================[" PACKAGE_NAME "] Start================\n")
#define DEBUG_PRINT_PROGRAM_END() DEBUG_PRINT(DEBUG:, "================[" PACKAGE_NAME "] End================\n")

#define DEBUG_PRINT_D( message ) DEBUG_PRINT(DEBUG:, message)
#define DEBUG_PRINT2_D( f, a ) DEBUG_PRINT2(DEBUG:, f, a)
#define DEBUG_PRINT3_D( f, a, b ) DEBUG_PRINT3(DEBUG:, f, a, b)

#define DEBUG_PRINT_I( message ) DEBUG_PRINT(INFO:, message)
#define DEBUG_PRINT2_I( f, a ) DEBUG_PRINT2(INFO:, f, a)
#define DEBUG_PRINT3_I( f, a, b ) DEBUG_PRINT3(INFO:, f, a, b)

#define DEBUG_PRINT_W( message ) DEBUG_PRINT(WARNING:, message)
#define DEBUG_PRINT2_W( f, a ) DEBUG_PRINT2(WARNING:, f, a)
#define DEBUG_PRINT3_W( f, a, b ) DEBUG_PRINT3(WARNING:, f, a, b)

#define DEBUG_PRINT_E( message ) DEBUG_PRINT(ERROR:, message)
#define DEBUG_PRINT2_E( f, a ) DEBUG_PRINT2(ERROR:, f, a)
#define DEBUG_PRINT3_E( f, a, b ) DEBUG_PRINT3(ERROR:, f, a, b)

#endif
