/*
 *  Canon Inkjet Printer Driver for Linux
 *  Copyright CANON INC. 2022
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
 * NOTE:
 *  - As a special exception, this program is permissible to link with the
 *    libraries released as the binary modules.
 *  - If you write modifications of your own for these programs, it is your
 *    choice whether to permit this exception to apply to your modifications.
 *    If you do not wish that, delete this exception.
*/

#ifndef _LIBCNSGRASTER_H_
#define _LIBCNSGRASTER_H_

#include <stdint.h>
#include "com_util.h"
#include "libcnivec.h"

#define SGRASTER_SUCCESS     0
#define SGRASTER_FAIL        1

#define LIBNAME_SGRASTER                    "libcnsgraster.so"

#define EXPORT_SGRCREATEENCODER             "sgrCreateEncoder"
#define EXPORT_SGRDESTROYENCODER            "sgrDestroyEncoder"
#define EXPORT_SGRSTARTIMAGE                "sgrStartImage"
#define EXPORT_SGRENCODEIMAGE               "sgrEncodeImage"
#define EXPORT_SGRFINISHIMAGE               "sgrFinishImage"

typedef void* sgrencoder;

typedef struct
{
    unsigned int width;
    unsigned int bytesPerLine;
    unsigned int resolution;
    unsigned int margins[2];
}page_header;

typedef struct
{
    unsigned int maxBandLines;
    unsigned int maxDataSize;
    fnIvecSendSendData fnSendData;
    FILE *fp;
}encoder_settings;

typedef sgrencoder (*fnSgrCreateEncoder)(page_header *header, encoder_settings *settings, option_list *options);
typedef void (*fnSgrDestroyEncoder)(sgrencoder enc);
typedef int (*fnSgrStartImage)(sgrencoder enc);
typedef int (*fnSgrEncodeImage)(sgrencoder enc, uint8_t *data, int lines);
typedef int (*fnSgrFinishImage)(sgrencoder enc);

#endif
