/*
 *  CUPS add-on module for Canon Inkjet Printer.
 *  Copyright CANON INC. 2022
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
 * NOTE:
 *  - As a special exception, this program is permissible to link with the
 *    libraries released as the binary modules.
 *  - If you write modifications of your own for these programs, it is your
 *    choice whether to permit this exception to apply to your modifications.
 *    If you do not wish that, delete this exception.
*/

#ifndef _IMAGE_H_
#define _IMAGE_H_

#include <stdint.h>
#include <cups/raster.h>

#define WHITE 255

typedef struct
{
  cups_raster_iocb_t iocb;  /* IO callback */
  void *ctx;                /* Context pointer for IO callback */
} iocb_t;

typedef struct
{
  int srcWidth;
  int srcHeight;
  uint8_t *srcData;
  int numColors;
  int dstWidth;
  int dstHeight;
  int marginWidth;
  int marginHeight;
  int quotientW;
  int restW;
  int quotientH;
  int restH;
  int currPosH;
  int prevPosH;
  int totalRestH;
  int totalReadLines;
  iocb_t iocb;
} image_scaler;

image_scaler *createImageScaler(cups_page_header2_t *cupsHeader, int out_w, int out_h);
void setImageScalerIO(image_scaler *imageScaler, cups_raster_iocb_t iocb, void *ctx);
int scaleImageData(image_scaler *imageScaler, int lines, uint8_t *data);
void destroyImageScaler(image_scaler *imageScaler);

#endif